<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Service\Sm00001000LancamentoPropostaService as PropostaService;
use Teknisa\SM\Service\Sm00004000ContratoService as ContratoService;
use Teknisa\Libs\Util\SMTP as SMTPService;
use Teknisa\SM\Util\Utilities;
use Teknisa\SM\Service\Sm00001000DocumentoPropostaService as DocumentoService;
use Teknisa\SM\Service\Sm00001000ItemLancamentoPropostaService;
use Teknisa\SM\Controller\BirtReport;
use Teknisa\Libs\Util\Environment;
use Teknisa\SM\Util\ConsultaInscricaoRF;

class Sm00001000LancamentoPropostaController extends SMCrud {
    
    protected $dataSourceName = "fct_orcamento_widget";
    protected $dataSourceNameToSave = 'fct_orcamento';
    protected $newCode;
    protected $propostaService;
    protected $contratoService;
    protected $smtpService;
    protected $documentoService;
    protected $birtController;
    protected $fileServerBaseUrl;
    protected $itensService;
    protected $login;
    protected $senha;
    
    public function __construct($crudService, Environment $environment, NewCode $newCode, PropostaService $propostaService, ContratoService $contratoService, DocumentoService $documentoService, BirtReport $birtController, $fileServerBaseUrl, Sm00001000ItemLancamentoPropostaService $itensService, $login, $senha) {
        parent::__construct($crudService, $environment);
        $this->newCode             = $newCode;
        $this->propostaService     = $propostaService;
        $this->contratoService     = $contratoService;
        $this->documentoService    = $documentoService;
        $this->birtController      = $birtController;
        $this->fileServerBaseUrl   = $fileServerBaseUrl;
        $this->itensService        = $itensService;
        $this->login = $login;
        $this->senha = $senha;
    }
    
    /**
     * Faz a busca dos registros no banco de dados, trazendo os Escopos de Proposta concatenados em uma coluna só.
     * 
     * @param Request\Filter $request
     * @param Response $response
     */
    public function find(Request\Filter $request, Response $response) {
        try {
            $request->setParameter("dbname", $this->dataSourceName);
            parent::find($request, $response);
            $erro = $response->getError();
            if ($erro) {
                throw new \Exception($erro->getMessage(), $erro->getErrorCode());
            }
            
            $rows = $response->getDataSets()[0]->getRows();
            foreach ($rows as &$row) {
                $row["NRTIPOORCAMENTO"] = Utilities::getArrayDeString($row["NRTIPOORCAMENTO"], true);
                $row["NMTIPOORCAMENTO"] = Utilities::getArrayDeString($row["NMTIPOORCAMENTO"], false, ";");
                $row["IDTIPOORCA"] = Utilities::getArrayDeString($row["IDTIPOORCA"]);
                $row["IDUTILIZAVARPRECO"] = Utilities::getArrayDeString($row["IDUTILIZAVARPRECO"]);
                $row["NRVENDEDOR"] = Utilities::getArrayDeString($row["NRVENDEDOR"], true);
                $row["NMVENDEDOR"] = Utilities::getArrayDeString($row["NMVENDEDOR"]);
            }
            unset($row);
            $response->setDataSets(array(new DataSet("fct_orcamento_widget", $rows)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    
    /**
     * Salva a Proposta e seus Escopos, chamando as procedures CRIA_MNEMONICO e FCT_GERA_DADOS_PROPOSTA.
     * 
     * @param Request $request
     * @param Response $response
     */
    public function save(Request $request, Response $response) {
        try {
            $request->setParameter("dbname", $this->dataSourceName);
            
            $nrorg = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            
            $qtdLinhas = count($request->getDataSet()->getRows());
            $row = $request->getDataSet()->getRows()[$qtdLinhas-1];
                
            $escopos = $row["NRTIPOORCAMENTO"];
            $modelo = $row["NRORCAMENTOMODELO"];
            $parcNegocio = $row["NRPARCNEGOCIO"];
            $row["NRTIPOORCAMENTO"] = null;
            
            $vendedores = $row["NRVENDEDOR"];
            $row["NRVENDEDOR"] = null;
            
            if ($row["__is_new"]) {
                
                $nrseqorcamento = $this->newCode->getCodeByTableName("NRSEQORCAMENTO", $nrorg, 1, 10, true);
                $row["NRSEQORCAMENTO"] = $nrseqorcamento;
                
                parent::save($request, $response);
                $erro = $response->getError();
                if ($erro) {
                    throw new \Exception($erro->getMessage(), $erro->getErrorCode());
                }

                $response->setDataSets(array());
                
                if (!empty($escopos)) {
                    if (!is_array($escopos))
                        $escopos = array($escopos);
                    
                    $this->salvarEscopos($escopos, $modelo, $nrseqorcamento, $nrorg, $request->getUserId(), $row["__is_new"]);
                }
                
                $mnemonico = $this->propostaService->executarProcedureCriaMnemonico($nrorg, "O", $nrseqorcamento);
                
                // Inserir Endereço
                $this->propostaService->inserirEnderecoProposta($nrseqorcamento, $parcNegocio, $nrorg);
                
                // Inserir itens Padrão do Modelo
                $this->propostaService->inserirItensPadraoProposta($nrseqorcamento, $modelo, $nrorg);
                
                // Atualizar valor da proposta
                $this->propostaService->atualizaValorProposta($nrseqorcamento, $nrorg);
                
                // Inserir Documento
                $this->propostaService->inserirDocumentosProposta($nrseqorcamento, $modelo, $nrorg, $cdoperador);

                /*$this->propostaService->executarProcedureFctGeraDadosProposta($nrseqorcamento, $nrorg);
                $this->propostaService->anexaDocumento($nrseqorcamento, $nrorg);*/

                $columnsToReturn = $this->crudService->getColumnsToReturn();
                $columnsToReturn[0]["NRSEQORCAMENTO"] = $nrseqorcamento;
                $columnsToReturn[0]["NRORCAMENTO"]    = $mnemonico;
                $columnsToReturn[0]["NRORG"]    = $nrorg;
                $response->addDataSet(new DataSet("columnsToReturn", $columnsToReturn));
                
                if (!empty($vendedores)) {
                    if (!is_array($vendedores)) {
                        $vendedores = array($vendedores);
                    }
                    
                    $this->salvarVendedores($vendedores, $nrseqorcamento, $nrorg, $cdoperador);
                }
            } else {
                parent::save($request, $response);
                $nrseqorcamento = $row["NRSEQORCAMENTO"];
                /* DEPRECIADO ATÉ DAR ERRO
                $this->propostaService->excluirEscopos($nrseqorcamento, $nrorg);
                if (!empty($escopos)) {
                    if (!is_array($escopos))
                        $escopos = array($escopos);
                    
                    $this->salvarEscopos($escopos, $modelo, $nrseqorcamento, $nrorg, $request->getUserId(), $row["__is_new"]);
                }*/
            }
            $response->addDataSet(new DataSet("NRSEQORCAMENTO", array($nrseqorcamento)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Salva os Escopos da Proposta.
     * 
     * @param integer[] $escopos
     * @param integer $modelo
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     * @param mixed[] $userId
     */
    private function salvarEscopos($escopos, $modelo, $nrseqorcamento, $nrorg, $userId, $isNewProposta) {
        try {
            $dataset  = array();
            $operador = $this->environment->getCdOperador();
            
            $qtEscopos = count($escopos);
            
            if ($qtEscopos != 0) {
                foreach ($escopos as $escopo) {
                    $nrrelacescopoproposta = $this->newCode->getCodeByTableName("FCT_RELACESCOPOPROPOSTA", $nrorg, 1, 10, true);
                    
                    $documento = null;
                    $cdfilial  = null;
                    
                    $documentoAux = $this->propostaService->buscaModeloDocumento($modelo, $escopo, $nrorg); 
                    if ($documentoAux) {
                        $documento = $documentoAux[0]["NRSEQMODDOCFCT"];
                        $cdfilial  = $documentoAux[0]["CDFILIAL"];
                    }
                    
                    $dataset[] = array(
                        "__is_new"              => true,
                        "NRRELACESCOPOPROPOSTA" => $nrrelacescopoproposta,
                        "NRSEQORCAMENTO"        => $nrseqorcamento,
                        "NRTIPOORCAMENTO"       => $escopo,
                        "NRSEQMODDOCFCT"        => $documento,
                        "CDFILIAL"              => $cdfilial,
                        "NRORG"                 => $nrorg,
                        "IDATIVO"               => "S"
                    );
                    
                    /*if ($qtEscopos == 1) {
                        $this->propostaService->preencheParamFatProposta($nrseqorcamento, $escopos, $nrorg);   
                    }

                    if($isNewProposta)
                        $this->propostaService->preencheParamItFatProposta($nrseqorcamento, $escopos, $nrorg);*/
                }
            }
            $requestRelac = new Request\DataSet(new DataSet("", $dataset), "product#/fct_relacescopoproposta/save", "POST", $userId);
            $response = new Response();
            $this->dataSourceNameToSave = "fct_relacescopoproposta";
            $requestRelac->setParameter('dbname', 'fct_relacescopoproposta');
            parent::save($requestRelac, $response);
            $this->dataSourceNameToSave = "fct_orcamento";
            
            $erro = $response->getError();
            if ($erro) {
                throw new \Exception($erro->getMessage(), $erro->getErrorCode());
            }
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Salva os Vendedores da Proposta.
     * 
     * @param integer[] $vendedores
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     * @param mixed #userId
     */
    private function salvarVendedores(array $vendedores, $nrseqorcamento, $nrorg, $cdoperador) {
        try {
            $qtdVendedores = count($vendedores);
            
            if ($qtdVendedores > 0) {
                foreach ($vendedores as $indice => $vendedor) {
                    $idvenpriorca = ($indice == 0) ? "S" : "N";
                    $vrpeparticipavenda = 100.0 / $qtdVendedores;

                    $this->propostaService->salvarVendedor($nrseqorcamento, $vendedor, null, $vrpeparticipavenda, $idvenpriorca, "S", $nrorg, $cdoperador);
                }
            }
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Salva a Composição da Proposta.
     * 
     * @param Request $request
     * @param Response $response
     */
    public function inserirTudo(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrseqorcamento    = $row["NRSEQORCAMENTO"];
            $escopos           = $row["NRTIPOORCAMENTO"];
            $nrorcamentomodelo = $row["NRORCAMENTOMODELO"];
            $medidas           = $row["MEDIDAS"];
            $itens             = $row["ITENS"];
            $interlocutor      = $row["INTERLOCUTOR"];
            
            $this->propostaService->inserirTudo($nrseqorcamento, $escopos, $nrorcamentomodelo, $medidas, $itens, null, $interlocutor);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function validaOrcamentoValidos(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrorcamentomodelo    = $row["NRORCAMENTOMODELO"];
            $nrorg                = $row["NRORG"];
            $result = $this->propostaService->validaOrcamentoValidos($nrorcamentomodelo, $nrorg);
            $response->addDataSet(new DataSet("modeloInativo", $result));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Cancela a Proposta.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function cancelarProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg          = $row["NRORG"];
            
            $propostas = array($nrseqorcamento);
            
            /*$propostasFilhas = $this->propostaService->getCodigoPropostasFilhas($nrseqorcamento, $nrorg);
            if (is_array($propostasFilhas)) {
                $propostas = array_merge($propostas, $propostasFilhas);
            }*/
            
            $contratos = $this->contratoService->getCodigoContratosDasPropostas($propostas, $nrorg);
            if (is_array($contratos)) 
                $this->contratoService->reprovarContratos($contratos, $nrorg);

            $this->propostaService->atualizarSituacaoPropostas("CANCELADO", $propostas, $nrorg);
            //$this->itensService->atualizarAgendamentoPendente($nrseqorcamento, $nrorg);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Retorna os contratos relacionados com a proposta que estão em situações diferentes de 
     * Pendente
    **/
    public function getContratosDifPendentes(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $propostas = array($row["NRSEQORCAMENTO"]);
            $nrorg     = $this->environment->getNrOrg();
            $contratos = $this->contratoService->getCodigoContratosDasPropostas($propostas, $nrorg);
            if(is_array($contratos))
                $existeContrato = $this->contratoService->existeContratoDiferentesP($contratos, $nrorg);
            else
                $existeContrato = false;
                
            $response->addDataSet(new DataSet("fct_orcamento_widget", array("CONTRATOS" => $existeContrato)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Copia ou versiona a Proposta.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function copiarVersionarProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $tipo           = $row["TIPO"];
            $nrorg          = $this->environment->getNrOrg();
            $cdoperador     = $this->environment->getCdOperador();
            $propostaGerada = null;
            if($tipo == 'V' && $row["IDSITUACAOORCAMENTO"] == "ACEITO"){
                $propostas = array($nrseqorcamento);
                $contratos = $this->contratoService->getCodigoContratosDasPropostas($propostas, $nrorg);
                if (is_array($contratos)) 
                    $this->contratoService->reprovarContratos($contratos, $nrorg);
            }
            
            $propostaGerada = $this->propostaService->executarProcedureFctCopiaVersionaProposta($nrseqorcamento, $tipo, $cdoperador, $nrorg);
            $this->propostaService->anexarDocumentosPropostaCopiada($propostaGerada, $nrorg);
            if($tipo == 'V')
                $this->itensService->excluiItemAgendPendente($nrseqorcamento, null, $nrorg);
            
            $response->addDataSet(new DataSet("NRSEORCGERADO", array($propostaGerada)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * Validação ao Concluir Propostas
     */
    public function concluirProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg          = $row["NRORG"];
            
            $result = $this->propostaService->concluirProposta($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("validacao", array($result)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Aceita a Proposta.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function aceitarProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento    = $row["NRSEQORCAMENTO"];
            $nrorcamento       = isset($row["NRORCAMENTO"]) ? $row["NRORCAMENTO"] : false;
            $nrorg             = $row["NRORG"];
            $utilizaComposicao = $row["IDUTILIZACOMP"];
            $nrparcnegocio     = $row["NRPARCNEGOCIO"];
            $dtAceite          = $row["DTACEITEORCA"];
            $periodoExtendido  = isset($row["PERIODOEXTENDIDO"]) ? true : false;
            $dtFinVigContr     = false;
            if($periodoExtendido == true){
                $dtFinVigContr     = $row["DTFINVIGCONTR"];
            }
            $cdoperador = $this->environment->getCdOperador();
            $this->propostaService->validarModeloContrato($nrseqorcamento, $nrorg);
            $this->propostaService->aceitarProposta($nrseqorcamento, $nrorg, $utilizaComposicao, $nrparcnegocio, $cdoperador, $periodoExtendido, $dtFinVigContr, $nrorcamento, $dtAceite);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Atualiza o Documento, chamando a procedure FCT_SUB_MNE_DOC.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function atualizarDocumento(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrseqorcadoc   = $row["NRSEQORCADOC"];
            $nrorg          = $row["NRORG"];
            
            $nrseqorcadoc = $nrseqorcadoc . "_";
            
            $this->propostaService->executarProcedureFctSubMneDoc($nrseqorcamento, $nrseqorcadoc, $nrorg, "O", "S");
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Retorna o Remetente e os Destinatários padrão para enviar o documento da proposta por e-mail.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function getDadosPadraoEnviarEmail(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento  = $row["NRSEQORCAMENTO"];
            $nrorg           = $row["NRORG"];
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $filial          = null;
            
            $filial = $this->propostaService->buscaFilialEscopoDocumento($nrtipoorcamento, $nrseqorcamento, $nrorg)[0]["CDFILIAL"];
            
            $dadosEmail = $this->propostaService->getEmailParametrizado($nrorg, $filial);
            
            if(count($dadosEmail) == 1){
                $dadosEmail = $dadosEmail[0];
            } else {
                if(count($dadosEmail) <= 0){
                    throw new \Exception("Não há Parametrizações de E-mail para essa unidade."); 
                } else {
                    foreach($dadosEmail as $key=>$dadoEmail){
                        if($dadoEmail["CDFILIAL"] != null){
                            $dadosEmail = $dadosEmail[$key];
                            break;
                        }
                    }
                }
            }
            
            $remetente = $dadosEmail["DSREMETENTEEMAIL"];
            $assunto = $dadosEmail["DSASSUNTOEMAIL"];
            $corpoEmail = $dadosEmail["DSCORPOEMAIL"];
            
            if ($remetente == null) {
            $remetente = $this->propostaService->getEmailVendedorProposta($nrseqorcamento, $nrorg);
            }
            if (empty($remetente)) {
                $remetente = $this->propostaService->getEmailEmpresaProposta($nrseqorcamento, $nrorg);
            }
            
            if (empty($remetente)) {
                $response->setError(new Response\Error("Operação bloqueada.<br/>Não há e-mail de remetente cadastrado.", 500));
            }
            else {
                $emailInterlocutor = $this->propostaService->getEmailInterlocutorProposta($nrseqorcamento, $nrorg);
                
                
                $destinatarios = $emailInterlocutor;
                //$destinatarios = str_replace(",", ";", $destinatarios);
                //$destinatarios = trim($destinatarios);
                /*Realiza a troca do mnemõnicos pelo seu valores correspondente vindos do banco*/
                
                $dados = $this->propostaService->getCorpoParaEmailProposta($nrseqorcamento, $nrorg);
                $assunto = str_replace("[CODIGO]", $dados[0]["NRORCAMENTO"], $assunto);
                $assunto = str_replace("[REFERENCIA]", $dados[0]["DSREFERENCIAORCA"], $assunto);
                $assunto = str_replace("[DTPROPOSTA]", $dados[0]["DTREFORCAMENTO"], $assunto);
                $assunto = str_replace("[CLIENTE]", $dados[0]["NMPRINCIPALPARC"], $assunto);
                $assunto = str_replace("[VLRORCA]", $dados[0]["VRORCAMENTO"], $assunto);
                $assunto = str_replace("[DTHOJE]", date_create()->format("d/m/Y"), $assunto);
                
                $corpoEmail = str_replace("[CODIGO]", $dados[0]["NRORCAMENTO"], $corpoEmail);
                $corpoEmail = str_replace("[REFERENCIA]", $dados[0]["DSREFERENCIAORCA"], $corpoEmail);
                $corpoEmail = str_replace("[DTPROPOSTA]", $dados[0]["DTREFORCAMENTO"], $corpoEmail);
                $corpoEmail = str_replace("[CLIENTE]", $dados[0]["NMPRINCIPALPARC"], $corpoEmail);
                $corpoEmail = str_replace("[VLRORCA]", $dados[0]["VRORCAMENTO"], $corpoEmail);
                $corpoEmail = str_replace("[DTHOJE]", date_create()->format("d/m/Y"), $corpoEmail);

                $dataset = array(
                    "REMETENTE"      => $remetente,
                    "DESTINATARIOS"  => $destinatarios,
                    "DSASSUNTOEMAIL" => $assunto,
                    "DSCORPOEMAIL"   => $corpoEmail
                );
                
                $response->addDataSet(new DataSet("DADOS", $dataset));
            }
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Atualiza o Documento, chamando a procedure FCT_SUB_MNE_DOC.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function converteParaCliente(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrparcnegocio = $row["NRPARCNEGOCIO"];
            $operador      = $row["OPERADOR"];
            $nrorg         = $row["NRORG"];
            
            $this->propostaService->executarProcedureFctConversaoCliente($nrorg, $operador, $nrparcnegocio);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function validarPerfilAcesso(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();

            $nrparcnegocio      = $row["NRPARCNEGOCIO"];
            $nrorg              = $row["NRORG"];
            $propostaoucontrato = $row["PROPOUCONT"];
        
            $param = $this->propostaService->validarPerfilAcesso($nrparcnegocio, $nrorg, $propostaoucontrato);
            $response->addDataSet(new DataSet("validarperfil", array("PERFILACESSO" => $param)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Atualiza os itens escolhidos da Composição de Serviço da Proposta.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function atualizarComposicaoProposta(Request\Row $request, Response $response) {
        try {
            $row   = $request->getRow();
            $nrorg        = $this->environment->getNrOrg();
            $cdoperador   = $this->environment->getCdOperador();
            $proposta     = $row["PROPOSTA"];
            $elementos    = $row["ELEMENTOS"];
            $composicoes  = $row["COMPOSICOES"];
            $tptratamento = $row["TPTRATAMENTO"];
            
            $mensagem = $this->propostaService->atualizarItensProposta($proposta, $elementos, $composicoes, $nrorg, $cdoperador, $tptratamento, false);
            $response->addMessage(new Response\Message($mensagem));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Atualiza o valor da proposta com a somatória do valor de seus itens.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function atualizarValorProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            
            if (isset($row["NRORG"])) {
                $nrorg = $row["NRORG"];
            }
            else {
                $nrorg = $this->environment->getNrOrg();
            }
            
            $valor = $this->propostaService->atualizarValorProposta($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("FCT_ORCAMENTO", array("VRORCAMENTO" => $valor)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Atualiza os itens da proposta e seus valores de acordo com as alterações feitas nos tipos de medida variáveis.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function atualizarItensPropostaPelosTiposDeMedida(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $proposta     = $row["PROPOSTA"];
            $tptratamento = $row["TPTRATAMENTO"];
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            $this->propostaService->atualizarTipoDeMedidaProposta($proposta, $nrorg, $cdoperador, $tptratamento);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Retorna os itens da proposta já com os preços corretos para exibir no momento de inserção.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function getItensPropostaParaInserir(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $proposta            = $row["PROPOSTA"];
            $elementosEscolhidos = $row["ELEMENTOS_ESCOLHIDOS"];
            $composicoes         = $row["COMPOSICOES"];
            $medidas             = $row["MEDIDAS"];
            
            $itens = $this->propostaService->getItensPropostaParaInserir($proposta, $elementosEscolhidos, $composicoes, $medidas);
            $response->addDataSet(new DataSet("fct_itemorcamento", $itens));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Verifica se o parceiro de negócio é um vendedor.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function verificarSeEVendedor(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrparcnegocio = $row["NRPARCNEGOCIO"];
            
            $isVendedor = $this->propostaService->verificarSeEVendedor($nrparcnegocio);
            $response->addDataSet(new DataSet("DADOS", array("vendedor" => $isVendedor)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Gera o Documento da Proposta.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
  
    public function gerarDocumentoProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento  = $row["NRSEQORCAMENTO"];
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $nrorg           = $row["NRORG"];
            $idSituacao      = $row["IDSITUACAOORCAMENTO"];
            $idpermitedocx   = $row["IDPERMITEDOCX"];
            $caminhoArquivos = $this->documentoService->gerarDocumentoProposta($nrseqorcamento, $nrtipoorcamento, $nrorg, $idSituacao, $idpermitedocx);
            
            if (count($caminhoArquivos) > 0) {
                $escopos = "";
                $caminhosFisicos = array();
                foreach ($caminhoArquivos as $chave => $arq) {
                    $retorno[] = $arq["CAMINHO"];
                    
                    if($arq["NMTIPOORCAMENTO"])
                        $escopos = $escopos . ($escopos == "" ? "" : ", ") . $arq["NMTIPOORCAMENTO"]; 
                }
                
                if($escopos != "")
                    $response->addMessage(new Response\Message("Atenção!<br><br>Não foram gerados documentos para os seguintes escopos porque a proposta não possui itens ligados a eles: <br>" . $escopos));
                
                if (count($retorno) > 0) 
                    $response->addDataSet(new DataSet("documentos", array("links" => $retorno)));
                else 
                    throw new \Exception("Falha ao anexar o(s) documento(s) no FileServer.");
            } else {
                throw new \Exception("Falha ao gerar o(s) documento(s).");
            }
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    /**
     * Envia os Documentos da Proposta por e-mail.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function enviarDocumentoPorEmail(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento  = $row["NRSEQORCAMENTO"];
            $nrorg           = $row["NRORG"];
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $remetente       = $row["REMETENTE"];
            $destinatarios   = $row["DESTINATARIOS"];
            $assunto         = $row["ASSUNTO"];
            $idSituacao      = $row["IDSITUACAOORCAMENTO"];
            $corpo           = nl2br($row["CORPO"]);

            $caminhoArquivos   = $this->documentoService->gerarDocumentoProposta($nrseqorcamento, $nrtipoorcamento, $nrorg, $idSituacao, "P");
            $configuracaoEmail = $this->propostaService->getConfiguracoesEmail($nrorg)[0];
        
            if ($caminhoArquivos > 0) {
                $params["host"]       = $configuracaoEmail["DSHOSTEMAIL"];
                $params["username"]   = $configuracaoEmail["DSUSUARIOEMAIL"];
                $params["password"]   = $configuracaoEmail["DSSENHAEMAIL"];
                $params["port"]       = $configuracaoEmail["DSPORTAEMAIL"];
                
                if ($configuracaoEmail["IDSMTPSECURE"] != null){
                    
                    $params["smtpSecure"] = $configuracaoEmail["IDSMTPSECURE"];
                    $params["smtpAuth"] = true;
                }
                
                $this->smtpService  = new SMTPService($params);
                
                $destinatarios = str_replace(" ", "", $destinatarios);
                $destinatarios = explode(";", $destinatarios);
                
                $this->smtpService->setFrom($remetente);
                $this->smtpService->setFromName($remetente);
                $this->smtpService->setSubject($assunto);
                $tamanho  = 0;
                $arquivos = array();
                
                foreach ($caminhoArquivos as $arq)
                    $arquivos[] = $arq["DADOSDOCUMENTO"];

                foreach ($arquivos as $caminhoDocumento) {
                    $fileType = $caminhoDocumento["TYPE"]; 
                    $fileDir  = $caminhoDocumento["DSCAMINHOARQ"]; 
                    
                    $tamanho += filesize($fileDir);
                    $tamanho = ($tamanho/1024)/1024;
                    
                    if ($tamanho > 15){
                        unlink($fileDir);
                        throw new \Exception("Não foi possível enviar o E-mail. Não é permitido anexar documentos acima de 15Mb.");
                    } else {
                        $this->smtpService->addAttachment($fileDir);
                    }
                }
                
                $validaEnvioEmail = $this->smtpService->sendMail($corpo, $destinatarios);
                if(!$validaEnvioEmail)
                    throw new \Exception("Falha ao enviar E-mail.");
                
                foreach ($arquivos as $caminhoDocumento) {
                    if (is_file($caminhoDocumento["DSCAMINHOARQ"]))
                        unlink($caminhoDocumento["DSCAMINHOARQ"]);
                }
            } else {
                $response->setError(new Response\Error("Não foi possível gerar o(s) documento(s).", 500));
            }
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Retorna os tipos de medida variáveis relacionados aos elementos da proposta, 
     * separados por elemento raíz da árvore.
     * 
     * @param Request\Row $request
     * @param Response $response
     */
    public function getTiposMedidaVariaveisParaInserir(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $idElementos     = $row["ID_ELEMENTOS"];
            $elementosRaiz   = $row["ELEMENTOS_RAIZ"];
            $nrtipoorcamento = $row["ESCOPOS"];
            
            $nrorg = $this->environment->getNrOrg();
            
            $tiposMedida = $this->propostaService->getTiposMedidaVariaveisDosElementos($elementosRaiz, $idElementos, $nrtipoorcamento, $nrorg);
            $tiposMedida = $this->propostaService->duplicarMedidasParaElementosRaiz($tiposMedida, $elementosRaiz);
            
            $response->addDataSet(new DataSet("tipos_medida_variavel", $tiposMedida));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getDadosAnexo(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento   = $row["NRSEQORCAMENTO"];
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $idsituacaoorcamento = $row["IDSITUACAOORCAMENTO"];
            $nrorg = $row["NRORG"];
            
            //$nrorg = $this->environment->getNrOrg();
            
            
            $dadosAnexo = $this->documentoService->getDadosAnexo($nrseqorcamento, $nrtipoorcamento, $idsituacaoorcamento, $nrorg);
            
            $response->addDataSet(new DataSet("dadoAnexos", $dadosAnexo));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Retorna os escopos da proposta.
     */
    public function getEscoposProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg          = $row["NRORG"];
            
            $escopos = $this->propostaService->getEscoposProposta($nrseqorcamento, $nrorg);
            
            $response->addDataSet(new DataSet("escopos", $escopos));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Envia dados para a integração com o CRM
    **/
    public function enviarDadosCRM(Request\Row $request, Response $response){
        try {
            $rowDados = $request->getRow(); 
            $webServiceCRM = array(
                    "requisitante"=> array(
                        "operador"=> $rowDados["CDOPERADORLOGADO"],
                        "nrorg"   => $rowDados["NRORG"]
                    ),
                    "evolucao"=> array(
                        "data"        => $rowDados["DTEVOLUCAO"],
                        "sentido"     => $rowDados["SENTIDO"],
                        "operador"    => $rowDados["CDOPEREVOL"],
                        "contato"     => $rowDados["CDTIPOCONT"],
                        "motivo"      => $rowDados["CDMOTIEVOCON"],
                        "interlocutor"=> $rowDados["NRSEQINTERLOCUTOR"],
                        "resultado"   => $rowDados["NRSEQRESULEVOL"],
                        "descricao"   => $rowDados["TXEVOLCONT"]
                    ),
                    "oportunidade"=> array(
                        "nrseqoport"    => $rowDados["NRSEQOPORT"],
                        "fase"          => $rowDados["NRSEQFASENEGO"],
                        "valor_previsto"=> $rowDados["VRPREVOPORT"],
                        "termometro"    => $rowDados["NRTERMOPORTUNI"],
                        "novo_operador" => array(
                            "operador"=> $rowDados["CDNVOPERRESP"],
                            "parceiro"=> $rowDados["NRPARCRESP"]
                        ),
                        "nrseqcontato" => $rowDados["NRSEQCONTATO"],
                        "nrparcnegocio"=> $rowDados["NRPARCNEGOCIO"],
                        "fechamento"   => array(
                            "data"                     => $rowDados["DTREALFECHA"],
                            "resultado"                => $rowDados["NRSEQRESULEVOLOPORT"],
                            "valor"                    => $rowDados["VROPORT"],
                            "nrparcnegocio_concorrente"=> $rowDados["NRCONCORRENTE"],
                        )
                    ),
                    "proxima_tarefa"=> array(
                        "data"       => $rowDados["DTPLANFILACONTA"],
                        "operador"   => $rowDados["CDOPERREAL"],
                        "assunto"    => $rowDados["DSFILACONTATO"],
                        "gera_tarefa"=> $rowDados["IDGERPROXATIV"]
                    )
            );
            $nrorg = $rowDados["NRORG"];
            $retorno = $this->propostaService->enviarDadosCRM($nrorg, $webServiceCRM);
        
            if(!$retorno){
                throw new \Exception("Falha na integração com o CRM.");
            }
            
        }
        catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function salvarElementosAlteradosPeloUsuario(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $elementos = $row["ELEMENTOS"];
            
            $this->propostaService->salvarElementosAlteradosPeloUsuario($elementos);
        }
        catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Salva a alteração dos operadores responsáveis de N propostas
    **/
    public function salvaAlteracaoMassaOper(Request\Row $request, Response $response){
        try {
            $rows           = $request->getRow(); 
            $nrseqorcamento = $rows["NRSEQORCAMENTO"];
            $operador       = $rows["CDOPERRESPONSAVEL"];
            $nrorg          = $this->environment->getNrOrg();
            $nrseqorcamento = implode(",", $nrseqorcamento);
            $sql            = "NRSEQORCAMENTO IN($nrseqorcamento)";
            $this->propostaService->atualizaOperadorResponsavel($sql, $operador, $nrorg);
            
            //verifica e manda salvar o novo operador nos contratos relacionados 
            if($rows["ALTERACONTRATO"] == 'Y'){
                $sql = "NRSEQCONTRATO IN(SELECT NRSEQCONTRATO FROM FCT_REFEORCACONT WHERE NRSEQORCAMENTO IN($nrseqorcamento))";
                $this->contratoService->atualizaOperadorResponsavel($sql, $operador, $nrorg);
            }
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Gera um contato quando a proposta não está ligada a uma oportunidade
    **/
    public function geraContato(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $nrparcnegocio   = $row["NRPARCNEGOCIO"];
            $nrparcinter     = $row["NRPARCINTERLOCUTOR"];
            $dsrefcont       = $row["DSREFCONTATO"];
            $nrseqorcamento  = $row["NRSEQORCAMENTO"];
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $nrorg           = $this->environment->getNrOrg();
            $cdoperador      = $this->environment->getCdOperador();
            
            $nrcontato = $this->propostaService->geraContato($nrseqorcamento, $nrtipoorcamento, $nrorg, $nrparcnegocio, $dsrefcont, $cdoperador, $nrparcinter);
            $response->addDataSet(new DataSet("NRCONTATO", array($nrcontato)));
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * apaga um contato gerado quando a proposta não está ligada a uma oportunidade
    **/
    public function deletaContatoProposta(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $nrseqcontato    = $row["NRSEQCONTATO"];
            $nrorg           = $this->environment->getNrOrg();

            $this->propostaService->deletaContatoProposta($nrseqcontato, $nrorg);
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * inativa uma proposta e um contato com suas evoluções 
     * caso a proposta não seja apagada
    **/
    public function inativaPropContato(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $nrseqcontato    = $row["NRSEQCONTATO"];
            $nrseqorcamento  = $row["NRSEQORCAMENTO"];
            $nrorg           = $this->environment->getNrOrg();

            $this->propostaService->inativaPropContato($nrseqcontato, $nrseqorcamento, $nrorg);
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Altera o nrcontato da proposta
    **/
    public function updateContatoOrcamento(Request\Row $request, Response $response){
        try{
            $row            = $request->getRow();
            $nrseqcontato   = $row["NRSEQCONTATO"];
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg          = $this->environment->getNrOrg();
            $this->propostaService->alteraContatoProposta($nrseqorcamento, $nrorg, $nrseqcontato);
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * Retorna o parametro de autorização de 
     * geração de documentos em DOCX
    **/
    public function getParametroExtensaoDoc(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg = $this->environment->getNrOrg();
            $param = $this->propostaService->getParametroExtensaoDoc($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("IDPERMITEDOCX", $param));
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Atualiza os documentos da proposta na tabela 
     * de acordo com asituação do orcamento
    */
    /*public function atualizaDocumentoSituacao(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $idSituacao     = $row["IDSITUACAOORCAMENTO"];
            $nrorg          = $this->environment->getNrOrg();
            $this->propostaService->atualizaDocumentoSituacao($nrseqorcamento, $nrorg, $idSituacao);
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }*/
    
    /**
     * Retorna se ao menos um elemento da arvore de um serviço relacionado 
     * possui medida fixa
    **/
    public function getIdUsaMedidaFixada(Request\Row $request, Response $response){
        try{
            $row         = $request->getRow();
            $idelementos = $row["IDARVORE"];
            $cdservorca  = $row["CDSERVORCA"];
            $nrorg       = $this->environment->getNrOrg();
            $dataset = $this->propostaService->getIdUsaMedidaFixada($idelementos, $nrorg, $cdservorca);
            $response->addDataSet(new DataSet("getIdUsaMedidaFixada", $dataset));
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Guarda a variação de preço ligada na proposta no momento em que ela foi concluida
    **/
    public function salvarInfoServicoEPrecoOrca(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            $nrseqorcamento  = $row["NRSEQORCAMENTO"];
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $this->propostaService->salvarInfoServicoEPrecoOrca($nrseqorcamento, $nrtipoorcamento, $nrorg, $cdoperador);
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    /**
     * valida a quantidade medida fornecida para a variação da proposta 
    **/
    public function validarVariacaoPreco(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            $nrseqorcamento  = $row["NRSEQORCAMENTO"];
            $idSituacao      = $row["IDSITUACAOORCAMENTO"];
            $cdservorca      = $row["CDSERVORCA"];
            $qtMedidaOrca    = $row["QTMEDIDAORCA"];
            $cdmedidaserv    = $row["CDTPMEDIDASERV"];
            $vrUnitItemOrca  = $this->propostaService->validarVariacaoPreco($nrorg, $nrseqorcamento, $idSituacao, $cdservorca, $qtMedidaOrca, $cdmedidaserv);
            $response->addDataSet(new DataSet("fct_orcamento_widget", $vrUnitItemOrca));
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function buscarLinksDocumentosProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg = $this->environment->getNrOrg();
            
            $links = $this->propostaService->buscarLinksDocumentosProposta($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("links", $links));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function parcelarNegociacaoPorIgual(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrnegociacaoproposta = $row["NRNEGOCIACAOPROPOSTA"];
            $qtparcelas           = $row["QTPARCELAS"];
            $qtdiasintervalo      = $row["QTDIASINTERVALO"];
            $nrdiavencimento      = isset($row["NRDIAVENCIMENTO"]) ? $row["NRDIAVENCIMENTO"] : null;
            $qtcarenciadias       = isset($row["QTCARENCIADIAS"]) ? $row["QTCARENCIADIAS"] : null;
            $vrtotitemcomdesc     = $row["VRTOTITEMCOMDESC"];

            $this->propostaService->parcelarNegociacaoPorIgual($nrnegociacaoproposta, $qtparcelas, $qtdiasintervalo, $nrdiavencimento, $qtcarenciadias, $vrtotitemcomdesc);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function validarNegociacaoValores(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            
            $resultado = $this->propostaService->validarValorNegociacoesValores($nrseqorcamento);
            $response->addDataSet(new DataSet("validacao", array("resultado" => $resultado)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    /*public function replicarDescontoItensNegociacao(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrnegociacaoproposta = $row["NRNEGOCIACAOPROPOSTA"];
            $vrdescitem           = $row["VRDESCITEM"];
            
            $this->propostaService->replicarDescontoItensNegociacao($nrnegociacaoproposta, $vrdescitem);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }*/

    public function getQuantidadeItensNegociacaoProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrnegociacaoproposta = $row["NRNEGOCIACAOPROPOSTA"];
            $nrorg = $this->environment->getNrOrg();

            $quantidade = $this->propostaService->getQuantidadeItensNegociacaoProposta($nrnegociacaoproposta, $nrorg);
            $response->addDataSet(new DataSet("retorno", array("quantidade" => $quantidade)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function atualizarValoresNegociacaoAoEditarElemento(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrnegociacaoproposta   = $row["NRNEGOCIACAOPROPOSTA"];
            $nritemorcamentopai     = $row["NRITEMORCAMENTOPAI"];
            
            $valorNegociacao = $this->propostaService->atualizarValoresNegociacaoAoEditarElemento($nrnegociacaoproposta, $nritemorcamentopai);
            $response->addDataSet(new DataSet("retorno", array("valorNegociacao" => $valorNegociacao)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function desagruparItemNegociacao(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $negociacao     = $row["NEGOCIACAO"];
            $itemNegociacao = $row["ITEM"];
            
            $valorNegociacao = $this->propostaService->desagruparItemNegociacao($negociacao, $itemNegociacao);
            $response->addDataSet(new DataSet("retorno", array("valorNegociacao" => $valorNegociacao)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function atualizarValoresDescontoPorPeriodoDaNegociacao(Request\Row $request, Response $response) {
        try {
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();

            $row = $request->getRow();
            $valorNegociacao      = $row["VRTOTITEMCOMDESC"];
            $nrnegociacaoproposta = $row["NRNEGOCIACAOPROPOSTA"];

            $this->propostaService->atualizarValoresDescontoPorPeriodoDaNegociacao($valorNegociacao, $nrnegociacaoproposta, $nrorg, $cdoperador);
        }
        catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function atualizarParceiroNegociacoesProposta(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrparcnegocio  = $row["NRPARCNEGOCIO"];

            $this->propostaService->atualizarParceiroNegociacoesProposta($nrseqorcamento, $nrparcnegocio);
        }
        catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function validaPropReneg(Request\Row $request, Response $response) {
        try {
            $nrorg = $this->environment->getNrOrg();
            
            $row = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            
            $valida = $this->propostaService->validaPropReneg($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("PROPOSTA", $valida));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    /**
     * Valida a quantidade máxima de parcelas em uma negociação
    **/
    public function validarQuantidadeMaxParcelas(Request\Row $request, Response $response) {
        try {
            $row            = $request->getRow();
            $nrorg          = $this->environment->getNrOrg();
            $cdoperador     = $this->environment->getCdOperador();
            
            $idTpValidacao     = $row["IDTPVALIDACAO"];
            
            $nrtipoorcamento      = $row["NRTIPOORCAMENTO"];
            $nrnegociacaoproposta = $row["NRNEGOCIACAOPROPOSTA"];
            $nrmaxparcelas   = $this->propostaService->validarQuantidadeMaxParcelas($nrtipoorcamento, $nrnegociacaoproposta, $cdoperador, $nrorg);
            
            if($idTpValidacao == "PARCELAUNICA") {
                $nrmaxparcelas = $this->propostaService->validarQuantidadeParcelasInseridas($nrnegociacaoproposta, $nrmaxparcelas, $nrorg);
            }
            
            $response->addDataSet(new DataSet("fct_orcamento_widget", array("NRMAXPARCELAS" => $nrmaxparcelas)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    /**
     * Atualiza o valor da negociação de valores com a soma do itens e retorna o valor total sem desconto.
     */
    public function atualizarValorNegociacaoComSomaDosItens(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrnegociacaoproposta = $row["NRNEGOCIACAOPROPOSTA"];
            
            $nrorg = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();

            $valorNegociacao = $this->propostaService->atualizarValorNegociacaoComSomaDosItens($nrnegociacaoproposta, $nrorg, $cdoperador);
            $response->addDataSet(new DataSet("retorno", array("valorNegociacao" => $valorNegociacao)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function atualizarValoresNegociacaoAoEditarItemSemComposicao(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nritemorcamento = $row["NRITEMORCAMENTO"];
            $vrtotalitemorca = $row["VRTOTALITEMORCA"];
            
            $this->propostaService->atualizarValoresNegociacaoAoEditarItemSemComposicao($nritemorcamento, $vrtotalitemorca);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function excluirParcelasNegociacao(Request\Row $request, Response $response) {
        try {
            $row   = $request->getRow();
            $nrorg = $this->environment->getNrOrg();
            $nrnegociacaoproposta = $row["NRNEGOCIACAOPROPOSTA"];
            $this->propostaService->excluirParcelasNegociacao($nrnegociacaoproposta, $nrorg);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Valida se os dados da compêtencia estão válidos na proposta
    **/
    public function validarParametrosFaturamentoOrca(Request\Row $request, Response $response) {
        try {
            $row   = $request->getRow();
            $nrorg = $this->environment->getNrOrg();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            
            $this->propostaService->validarParametrosFaturamentoOrca($nrseqorcamento, $nrorg);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Valida se o operador logado pode diminuir o valor dos itens da proposta
    **/
    public function validarPermissaoAlteracaoQtMedida(Request\Row $request, Response $response) {
        try {
            $operador = $this->environment->getCdOperador();
            $nrorg    = $this->environment->getNrOrg(); 
            
            $permitirAlteracao = $this->propostaService->validarPermissaoAlteracaoQtMedida($operador, $nrorg);
            $response->addDataSet(new DataSet("fct_orcamento_widget", array("PERMITEDIMINUICAO" => $permitirAlteracao)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Retorna um bool determinado se a proposta sofreu desconto ou acréscimo
    **/
    public function validarExistenciaDescontoAcrescimoProposta(Request\Row $request, Response $response) {
        try {
            $row   = $request->getRow();
            $nrorg = $this->environment->getNrOrg(); 
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            
            $descontos  = $this->propostaService->getDescontosProposta($nrseqorcamento, $nrorg);
            $itens      = $this->propostaService->getItensProposta($nrseqorcamento, $nrorg);
            $possuiAlteracaoValor = count($descontos) > 0;
            
            if(!$possuiAlteracaoValor) {
                foreach($itens as $item) {
                    if($item["VRACRESCIMOITEM"] > 0) {
                        $possuiAlteracaoValor = true;
                        break;
                    }
                }
            }
            
            $response->addDataSet(new DataSet("fct_orcamento_widget", array($possuiAlteracaoValor)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function validaBloqAlteraValor(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $nrorg = $this->environment->getNrOrg();

            $idaltvrtabrpecprop = $this->propostaService->validaBloqAlteraValor($nrtipoorcamento, $nrorg);
            $response->addDataSet(new DataSet("retorno", array("idaltvrtabrpecprop" => $idaltvrtabrpecprop)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function atualizarMedidaVariavelServico(Request\Row $request, Response $response) {
        try {
            $nrorg = $this->environment->getNrorg();
            $cdoperador = $this->environment->getCdOperador();
            $row = $request->getRow();
            
            $qtmedidaorca = $this->propostaService->getSomaQuantidadeMedidaServicoProposta($row["NRSEQORCAMENTO"], $row["CDSERVORCA"], $nrorg);
            $row["QTMEDIDAORCA"] = $qtmedidaorca;
            
            $this->propostaService->inserirOuAtualizarMedidaVariavelServico($row, $nrorg, $cdoperador, true);
        }
        catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * realiza o update da proposta para incluir / alterar o campo "DSALTERACONTRATUAIS"
    **/
    public function updateDsAlteracoesContr(Request\Row $request, Response $response) {
        try {
            $row   = $request->getRow();
            $nrseqorcamento      = $row["NRSEQORCAMENTO"];
            $dsalteracontratuais = $row["DSALTERACONTRATUAIS"];
            
            $nrorg = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            
            $this->propostaService->updateDsAlteracoesContr($nrseqorcamento, $dsalteracontratuais, $nrorg, $cdoperador);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     *recebe os dados de "Alterações Contratuais"
    **/
    public function getAlteracaoContratual(Request\Row $request, Response $response) {
        try {
            $row   = $request->getRow();
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            
            $nrorg = $this->environment->getNrOrg();

            $resultado = $this->propostaService->getAlteracaoContratual($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("getAlteracaoContratual", array("resultado" => $resultado)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Valida se o operador tem acesso à página "Alterações Contratuais"
    **/
    public function validaAlteracoesContratuais(Request\Row $request, Response $response) {
        try {
            $nrorg = $this->environment->getNrOrg();

            $resultado = $this->propostaService->validaAlteracoesContratuais($nrorg);
            $response->addDataSet(new DataSet("validaAlteracoesContratuais", array("resultado" => $resultado)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * insere os signatários padrões de modelo de proposta que foram buscados na parametrização SM 
    **/
    public function inserirAssinaturasOrca(Request\Row $request, Response $response){
        try {
            $row      = $request->getRow();
            
            $nrorcamentomodelo = $row["NRORCAMENTOMODELO"];
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $interlocutor = $row["NRSEQINTERLOCUTOR"];
            $nrorg    = $this->environment->getNrorg();
            $operador = $this->environment->getCdOperador();
            
            $this->propostaService->inserirAssinaturasOrca($nrorcamentomodelo, $nrseqorcamento, $interlocutor, $nrorg, $operador);
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * A função "validaAssinaturaOrca" realiza a validação das assinaturas para evitar a inclusão repetida de um parceiro.
     */
    
    public function validaAssinaturaOrca(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $result = $this->propostaService->validaAssinaturaOrca($row);
            $response->addDataSet(new DataSet("validaAssinaturaOrca", array("valida" => $result)));

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Valida se o token da certsign está preenchido
     */
    public function validaIdCertsign(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            $nrseqorcamento = isset($row["NRSEQORCAMENTO"]) ? $row["NRSEQORCAMENTO"] : null;
            $nrorg = $this->environment->getNrorg();
            
            $result = $this->propostaService->validaIdCertsign($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("validaIdCertsign", $result));
            
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Envia novamente o e-mail de assinatura para os signatários que ainda não realziaram a assinatura
     */
    public function solicitarAssinatura(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $tipoorcamentos = $row["NRTIPOORCAMENTO"];
            $nrorg          = $this->environment->getNrorg();
            $operador       = $this->environment->getCdOperador();
            
            $result = $this->propostaService->solicitarAssinatura($nrseqorcamento, $tipoorcamentos, $nrorg, $operador);
            $response->addDataSet(new DataSet("solicitarAssinatura", array("resultado" => $result)));
            
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

     /**
     * Exclui o signatário do Certsign e altera a situação para 'Assinado Manualmente'.
     */
    public function assinadoManualmente(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            
            $signatarios    = $row["SIGNATARIO"];
            $checked        = $row["CHECKED"];
            $nrorg          = $this->environment->getNrorg();
            $operador       = $this->environment->getCdOperador();
            
            $result = $this->propostaService->assinadoManualmente($signatarios, $checked, $nrorg, $operador);
            $response->addDataSet(new DataSet("assinadoManualmente", array("resultado" => $result)));
            
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
     /**
     * Exclui o signatário do Certsign e altera a situação para 'Assinado Manualmente'.
     */
    public function assinadoManualmenteDoc(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            
            $signatarios    = $row["SIGNATARIO"];
            $checked        = $row["CHECKED"];
            $nrorg          = $this->environment->getNrorg();
            $operador       = $this->environment->getCdOperador();
            
            $result = $this->propostaService->assinadoManualmenteDoc($signatarios, $checked, $nrorg, $operador);
            $response->addDataSet(new DataSet("assinadoManualmenteDoc", array("resultado" => $result)));
            
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * valida se todas as assinaturas estão aprovadas para concluir a proposta.
     */
    public function validaAceiteCertsign(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg          = $this->environment->getNrorg();
            
            $result = $this->propostaService->validaAceiteCertsign($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("validaAceiteCertsign", array("resultado" => $result)));
            
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * A função "insereInterlocutor" realiza a inserção automática do interlocutor do parceiro
     */
    public function insereInterlocutor(Request\Row $request, Response $response){
        try {
            $nrorg    = $this->environment->getNrorg();
            $operador = $this->environment->getCdOperador();
            
            $row = $request->getRow();
            $nrseqorcamento    = $row["NRSEQORCAMENTO"];
            $interlocutor      = $row["NRSEQINTERLOCUTOR"];
            $interlocutorAnte  = $row["NRINTERLOCUTORANTE"];
            $nrorcamentomodelo = $row["NRORCAMENTOMODELO"];
            $this->propostaService->insereInterlocutor($nrseqorcamento, $interlocutor, $interlocutorAnte, $nrorg, $operador, $nrorcamentomodelo);
        }
        catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
     /**
     * A função "gerarDocumentoCertsign" realiza o upload e cria o documento no ambiente certsign
     */
    public function gerarDocumentoCertsign(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            
            $nrseqorcamento      = $row["NRSEQORCAMENTO"];
            $tipoorcamentos      = $row["NRTIPOORCAMENTO"];
            $nrorcamento         = $row["NRORCAMENTO"];
            $idsituacaoorcamento = $row["IDSITUACAOORCAMENTO"];
            $nrorg               = $this->environment->getNrorg();
            $operador            = $this->environment->getCdOperador();
            $result = $this->propostaService->gerarDocumentosEEnviarAoPortalDeAssinaturasEletronica($nrseqorcamento, $tipoorcamentos, $nrorg, $idsituacaoorcamento, $this->documentoService, $nrorcamento, $operador);
            
            $response->addDataSet(new DataSet("gerarDocumentoCertsign", array("resultado" => $result)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    
    /**
     * A função "inserirSignatario" realiza a inclusão de um novo signatário.
     */
    
    public function inserirSignatario(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $dados          = $row["DADOS"];
            $tipoorcamentos = $row["NRTIPOORCAMENTO"];
            
            $result = $this->propostaService->inserirSignatario($dados, $tipoorcamentos);
            
            $response->addDataSet(new DataSet("inserirSignatario", array("resultado" => $result)));

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
     /**
     * A função "excluirSignatariosCertsign" realiza a exclusão de um signatário no Certsign.
     */
    public function excluirSignatariosCertsign(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $nrseqorcamento   = $row["NRSEQORCAMENTO"];
            $nrassdigitalorca = $row["NRASSDIGITALORCA"];
            $tipoorcamentos   = $row["NRTIPOORCAMENTO"];
            $idsignatcertsign = $row["IDSIGNATCERTSIGN"];
            $nrcpfsignatario  = $row["NRCPFSIGNATARIO"];
            $nrorg            = $this->environment->getNrorg();
            $operador         = $this->environment->getCdOperador();
            
            foreach ($tipoorcamentos as $nrtipoorcamento){
            
                $result = $this->propostaService->excluirSignatariosCertsign($nrseqorcamento, $nrassdigitalorca, $nrtipoorcamento, $idsignatcertsign, $nrcpfsignatario, $nrorg, $operador);
            }
            
            $response->addDataSet(new DataSet("excluirSignatariosCertsign", array("resultado" => $result)));
            
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
     /**
     * A função "excluirDocumentoCertsign" realiza a exclusão do documento no Certsign.
     */
    
    public function excluirDocumentoCertsign(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $nrseqorcamento   = $row["NRSEQORCAMENTO"];
            $tipoorcamentos   = $row["NRTIPOORCAMENTO"];
            $nrorg            = $this->environment->getNrorg();
            $operador         = $this->environment->getCdOperador();
            
            foreach ($tipoorcamentos as $nrtipoorcamento){
            
                $this->propostaService->excluirDocumentoCertsign($nrseqorcamento, $nrtipoorcamento,  $nrorg, $operador);
            }

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * realiza o download do documento do ambiente Certsign 
    **/
    public function downloadDocEletrDigital(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            
            $nrseqorcamento   = $row["NRSEQORCAMENTO"];
            $nrtipoorcamento  = $row["NRTIPOORCAMENTO"];
            $nrorg            = $this->environment->getNrorg();

            $this->propostaService->downloadDocEletrDigital($nrseqorcamento, $nrtipoorcamento, $nrorg);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * realiza a atualização do Nr. de Parcelas da negociação
    **/
    public function atualizarNrParcelas(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $nrnegociacaoproposta = $row["NRNEGOCIACAOPROPOSTA"];
            $nrorg                = $this->environment->getNrorg();

            $this->propostaService->atualizarNrParcelas($nrnegociacaoproposta, $nrorg);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * realiza a atualização do Nr. de Parcelas da negociação
    **/
    public function habilitarAssinaturaEletrDigital(Request\Row $request, Response $response) {
        try{
            $row      = $request->getRow();
            $nrorg    = $this->environment->getNrorg();
            $operador = $this->environment->getCdOperador();

            $result = $this->propostaService->habilitarAssinaturaEletrDigital($row, $nrorg, $operador);
            
            $response->addDataSet(new DataSet("habilitaAssinatura", array("resultado" => $result)));

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Valida se é necessário filtrar os serviços na inserção de contratos manuais
    **/
    public function validaFiltroServico(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            
            $tipoorcamento = $row["NRTIPOORCAMENTO"];
            $nrorg         = $this->environment->getNrOrg();
            
            $result = $this->propostaService->validaFiltroServico($tipoorcamento, $nrorg);
            $response->addDataSet(new DataSet("validaFiltroServico", array("resultado" => $result)));
            
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    

    public function validaStatusAssinaturas(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            
            $nrseqorcamento = $row["NRSEQORCAMENTO"];
            $nrorg          = $this->environment->getNrOrg();
            
            $result = $this->propostaService->validaStatusAssinaturas($nrseqorcamento, $nrorg);
            $response->addDataSet(new DataSet("validaStatusAssinaturas", array("resultado" => $result)));
            
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
       
        /**
     * A função "insereOperadoresNotifica" realiza a inserção dos operadores do sistema que devem ser notificados.
     */
    public function insereOperadoresNotifica(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $nrassdigitalorca = $row["NRASSDIGITALORCA"];
            $operadores = $row["OPERADORES"];
            
            $this->propostaService->insereOperadoresNotifica($nrassdigitalorca, $operadores);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function recebeOrdenacaoENotificacoes(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            
            $orcamentoModelo = $row["NRORCAMENTOMODELO"];
            $idtpsignatario = $row["IDTPSIGNATARIO"];
            $nrorg          = $this->environment->getNrOrg();
            
            $result = $this->propostaService->recebeOrdenacaoENotificacoes($orcamentoModelo, $idtpsignatario, $nrorg);
            $response->addDataSet(new DataSet("recebeOrdenacaoENotificacoes", array("resultado" => $result)));
            
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function validaGeraDocCertisign(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            
            $orcamentoModelo = $row["NRORCAMENTOMODELO"];
            $nrorg          = $this->environment->getNrOrg();
            
            $result = $this->propostaService->validaGeraDocCertisign($orcamentoModelo, $nrorg);
            $response->addDataSet(new DataSet("validaGeraDocCertisign", array("resultado" => $result)));
            
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function fazerConsultaInscricao(Request\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $cpf = $row["NRCPFINTERLOC"];
            $dtNascimento = $row["DTNASCIMENTO"];
            $nrorg          = $this->environment->getNrOrg();
            $result = $this->propostaService->fazerConsultaInscricao($cpf, $dtNascimento, $nrorg);
            $response->addDataSet(new DataSet("request", array("resulted" => $result)));
            
        } catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    public function consultaDadosCPF(Request\Row $row, Response $response) {
        $row = $row->getRow();
        $cpf = $row["NRCPFINTERLOC"];
        $data = $row["DTNASCIMENTO"];
        $consulta = ConsultaInscricaoRF::consultaDadoRF($cpf, $this->login, $this->senha, $data);
        $response->addDataSet(new DataSet("CONSULTA", $consulta));
    }
}

?>